# Changelog

## v1.0.4

- Internal changes.
- Set section margin to 0

## v1.0.3

- Made minsize to -1 as it messes up grid.

## v1.0.2

- Fix binding issue on select widget.
## v1.0.1

- Fix pylint and mypy

## v1.0.0

- Releasing version 1.0.0

## v0.0.9

- Add "Section widget"
- Add better validation
- Add Events package for pub sub inside controller-view part.
- Add split/unsplit to splitview.
- Add Checkbox

## v0.0.8

- Add basic validation feedback.

## v0.0.6

- Make text label bindable.

## v0.0.5

- Add splitter window.
